Player

Struct Player 

pub struct Player {
    pub media_type: MediaType,
    pub file_input: InputMode,
    pub player_size: Vec2,
    pub player_scale: f32,
    pub player_state: PlayerState,
    pub elapsed_time: Duration,
    pub total_time: Duration,
    pub start_time: Duration,
    pub volume: Arc<AtomicI32>,
    pub transcript: Vec<TranscriptionData>,
    pub model_path: ModelPath,
    pub transcription_progress: TranscriptionProgress,
    /* private fields */
}
Holds relevant info to run the player

Fields

media_type: MediaType

Meta data information

file_input: InputModeplayer_size: Vec2

Player settings

player_scale: f32player_state: PlayerStateelapsed_time: Duration

Info related to control bar

total_time: Durationstart_time: Durationvolume: Arc<AtomicI32>

Audio related info

transcript: Vec<TranscriptionData>model_path: ModelPathtranscription_progress: TranscriptionProgress

Implementations

Source

impl Player

pub fn from_path(file_path: &str) -> Self

Initializes the Player

Takes an InputMode

To initialize with a filepath:

Player::new(InputMode::FilePath("your_path_here".to_string()))

Use the Player.ui() function to display it

Look at the README to have a more in depth approach to adding a Player to your egui project Or look at the example in examples/main.rs

pub fn from_bytes(bytes: Vec<u8>) -> Self

To initialize with bytes (Vec<u8>):

Player::new(InputMode::Bytes(your_bytes))

Use the Player.ui() function to display it

Look at the README to have a more in depth approach to adding a Player to your egui project Or look at the example in examples/main.rs

pub fn set_transcript_settings(&mut self, setting: TranscriptionSettings)

Configure transcription settings by changing the TranscriptionSettings enum

pub fn set_model_download_path(&mut self, file_path: String)

Configure where model is downloaded

pub fn set_player_scale(&mut self, scale: f32)

Allows you to rescale the player (Note: Currently non-functional)

pub fn ui(&mut self, ui: &mut Ui) -> Response

Call this to show the player on screen